.. _people:

======
People
======

OceanSpy is open source and we are always looking for new collaborators.
Add yourself to the list_! 

.. _list: https://github.com/malmans2/oceanspy/blob/master/docs/data/people.yml

